@@ -18,6 +18,7 @@
 // Copyright (C) 2005 Kristian Høgsberg <krh@redhat.com>
 // Copyright (C) 2013 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2014 Fabio D'Urso <fabiodurso@hotmail.it>
+// Copyright (C) 2020 Adam Reichold <adam.reichold@t-online.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -27,29 +28,30 @@
 #ifndef ERROR_H
 #define ERROR_H
 
-#include <stdarg.h>
+#include <cstdarg>
 #include "poppler-config.h"
-#include "goo/gtypes.h"
+#include "goo/gfile.h"
 #include "goo/GooString.h"
 
-enum ErrorCategory {
-  errSyntaxWarning,    // PDF syntax error which can be worked around;
-                       //   output will probably be correct
-  errSyntaxError,      // PDF syntax error which can be worked around;
-                       //   output will probably be incorrect
-  errConfig,           // error in Xpdf config info (xpdfrc file, etc.)
-  errCommandLine,      // error in user-supplied parameters, action not
-                       //   allowed, etc. (only used by command-line tools)
-  errIO,               // error in file I/O
-  errNotAllowed,       // action not allowed by PDF permission bits
-  errUnimplemented,    // unimplemented PDF feature - display will be
-                       //   incorrect
-  errInternal          // internal error - malfunction within the Xpdf code
+enum ErrorCategory
+{
+    errSyntaxWarning, // PDF syntax error which can be worked around;
+                      //   output will probably be correct
+    errSyntaxError, // PDF syntax error which can be worked around;
+                    //   output will probably be incorrect
+    errConfig, // error in Xpdf config info (xpdfrc file, etc.)
+    errCommandLine, // error in user-supplied parameters, action not
+                    //   allowed, etc. (only used by command-line tools)
+    errIO, // error in file I/O
+    errNotAllowed, // action not allowed by PDF permission bits
+    errUnimplemented, // unimplemented PDF feature - display will be
+                      //   incorrect
+    errInternal // internal error - malfunction within the Xpdf code
 };
 
-extern void setErrorCallback(void (*cbk)(void *data, ErrorCategory category,
-					 Goffset pos, const char *msg),
-			     void *data);
+using ErrorCallback = void (*)(ErrorCategory category, Goffset pos, const char *msg);
+
+extern void setErrorCallback(ErrorCallback cbk);
 
 extern void CDECL error(ErrorCategory category, Goffset pos, const char *msg, ...) GOOSTRING_FORMAT;
 
