@@ -604,8 +604,11 @@ FormField::FormField(PDFDoc *docA, Object &&aobj, const Ref aref, FormField *par
 
     obj1 = Form::fieldLookup(dict, "Q");
     if (obj1.isInt()) {
-        quadding = static_cast<VariableTextQuadding>(obj1.getInt());
-        hasQuadding = true;
+        const int aux = obj1.getInt();
+        hasQuadding = aux == quaddingLeftJustified || aux == quaddingCentered || aux == quaddingRightJustified;
+        if (likely(hasQuadding)) {
+            quadding = static_cast<VariableTextQuadding>(aux);
+        }
     }
 
     obj1 = dict->lookup("T");
@@ -2005,6 +2008,7 @@ Form::Form(PDFDoc *docA, Object *acroFormA)
     obj1 = acroForm->dictLookup("Fields");
     if (obj1.isArray()) {
         Array *array = obj1.getArray();
+        std::set<Ref> alreadyReadRefs;
         for (int i = 0; i < array->getLength(); i++) {
             Object obj2 = array->get(i);
             const Object &oref = array->getNF(i);
@@ -2018,6 +2022,11 @@ Form::Form(PDFDoc *docA, Object *acroFormA)
                 continue;
             }
 
+            if (alreadyReadRefs.find(oref.getRef()) != alreadyReadRefs.end()) {
+                continue;
+            }
+            alreadyReadRefs.insert(oref.getRef());
+
             if (numFields >= size) {
                 size += 16;
                 rootFields = (FormField **)greallocn(rootFields, size, sizeof(FormField *));
